# Plantilla de programas para Python

El objetivo de este repositorio es servir de referencia a las distintas herramientas que se están desarrollado dentro de la organización para estandar las siguientes funcionalidades en cada uno de los entornos de trabajo:

- Workflow develop-master
- Empaquetamiento con Pipy
- Ejecución del Análisis estático del código en integración continua
- Ejecución de la Generación automatica de Documentación en integración continua
- Ejecución de pruebas unitarias en integración continua
